-- Core file, contains the module logic.

ForceEnchant = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0","AceEvent-2.0","AceDB-2.0","AceDebug-2.0");
ForceEnchant:RegisterDB("ForceEnchantDB", "ForceEnchantDBPC");

local L = AceLibrary("AceLocale-2.2"):new("ForceEnchant");
local D = AceLibrary("AceLocale-2.2"):new("ForceEnchant-Debug");
local O = AceLibrary("AceLocale-2.2"):new("ForceEnchant-Option");

local opts = { 
    type='group',
    args = {
        replace = {
            type    = 'toggle',
            name    = O['Replace-Name'],
            desc    = O['Replace-Desc'],
            set     = 'toggleReplace',
            get     = 'getReplace',
        },
        inform = {
            type        = 'toggle',
            name        = O['Inform-Name'],
            desc        = O['Inform-Desc'],
            set         = 'toggleInform',
            get         = 'getInform',
            disabled    = '~getReplace',
        },
    },
};

ForceEnchant:RegisterChatCommand(L["Slash-Commands"],opts);
ForceEnchant:RegisterDefaults("profile", {
    replace = false,
    inform  = true,
} );

function ForceEnchant:toggleReplace()
    self.db.profile.replace = not self.db.profile.replace;
end

function ForceEnchant:getReplace()
    return self.db.profile.replace;
end

function ForceEnchant:toggleInform()
    self.db.profile.inform = not self.db.profile.inform;
end

function ForceEnchant:getInform()
    return self.db.profile.inform;
end

function ForceEnchant:OnInitialize()
    -- Called when the addon is loaded
    self:LevelDebug(2,D["Init"]);
end

function ForceEnchant:OnEnable()
    -- Called when the addon is enabled
    self:LevelDebug(2,D["Enabled"]);
    self:RegisterEvent("REPLACE_ENCHANT");
end

function ForceEnchant:REPLACE_ENCHANT( olde, newe )
    -- Called when the REPLACE_ENCHANT event is fired
    self:LevelDebug(2,D["Event fired"]);
    self:doInform( olde, newe );
    self:doReplace();
end

function ForceEnchant:doInform( olde, newe )
    self:LevelDebug(2,D["Inform"] .. ' ' .. self:doBool(self:getInform()));
    if self:getReplace() and self:getInform() then
        self:Print( string.format( '%s {%s} => {%s}', L["Replace warning supressed"], olde, newe) );
    end
end

function ForceEnchant:doReplace()
    self:LevelDebug(2,D["Replace"] .. ' ' .. self:doBool(self:getReplace()));
    if self:getReplace() then
        self:LevelDebug(2,D["Replacing enchant"]);
        ReplaceEnchant(); --wow api.
    end
end
function ForceEnchant:doBool(b)
    if b then
        return 'true';
    end
    return 'false';
end
function ForceEnchant:OnDisable()
    -- Called when the addon is disabled
    self:LevelDebug(2,D["Disabled"]);
end

